@@ -86,7 +86,7 @@ class Dummy2x2Plugin(Dummy1x1Plugin):
 plugin_registry.register(Dummy2x2Plugin)
 
 # ********************************************************************************
-# ******************************* Big dummy plugin *******************************
+# ******************************* Dummy 3x3 plugin *******************************
 # ********************************************************************************
 
 class Dummy3x3Plugin(Dummy1x1Plugin):
@@ -100,6 +100,37 @@ class Dummy3x3Plugin(Dummy1x1Plugin):
 
 plugin_registry.register(Dummy3x3Plugin)
 
+
+# ********************************************************************************
+# ******************************* Dummy 4x4 plugin *******************************
+# ********************************************************************************
+
+class Dummy4x4Plugin(Dummy1x1Plugin):
+    """
+    Dummy4x4 dashboard plugin.
+    """
+    uid = 'dummy_4x4'
+    name = _("Dummy")
+    group = _("Dummy")
+
+
+plugin_registry.register(Dummy4x4Plugin)
+
+# ********************************************************************************
+# ******************************* Dummy 5x5 plugin *******************************
+# ********************************************************************************
+
+class Dummy5x5Plugin(Dummy1x1Plugin):
+    """
+    Dummy5x5 dashboard plugin.
+    """
+    uid = 'dummy_5x5'
+    name = _("Dummy")
+    group = _("Dummy")
+
+
+plugin_registry.register(Dummy5x5Plugin)
+
 # ********************************************************************************
 # ******************************* Registering the widgets ************************
 # ********************************************************************************
