@@ -10,7 +10,7 @@ FIT_METHOD_CROP_SCALE = 'scale'
 FIT_METHOD_FIT_WIDTH = 'fit_width'
 FIT_METHOD_FIT_HEIGHT = 'fit_height'
 
-DEFAULT_FIT_METHOD = FIT_METHOD_CROP_SCALE
+DEFAULT_FIT_METHOD = FIT_METHOD_CROP_CENTER
 
 FIT_METHODS_CHOICES = (
     (FIT_METHOD_CROP_SMART, _("Smart crop")),
