@@ -15,6 +15,7 @@ from django.contrib.staticfiles.management.commands import collectstatic
 from django.conf import settings
 
 from selenium.webdriver.firefox.webdriver import WebDriver
+from selenium.webdriver.remote.webdriver import WebDriver as RemoveWebDriver
 from selenium.webdriver.support.wait import WebDriverWait
 
 from dash.discover import autodiscover
@@ -229,7 +230,16 @@ class DashBrowserTest(LiveServerTestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.selenium = WebDriver()
+        try:
+            username = os.environ["SAUCE_USERNAME"]
+            access_key = os.environ["SAUCE_ACCESS_KEY"]
+            capabilities["tunnel-identifier"] = os.environ["TRAVIS_JOB_NUMBER"]
+            hub_url = "%s:%s@localhost:4445" % (username, access_key)
+            cls.selenium = RemoveWebDriver(
+                desired_capabilities=capabilities, command_executor="http://%s/wd/hub" % hub_url
+                )
+        except:
+            cls.selenium = WebDriver()
         super(DashBrowserTest, cls).setUpClass()
 
         setup_dash()
@@ -249,10 +259,10 @@ class DashBrowserTest(LiveServerTestCase):
         """
         Test add any single plugin.
 
-        :param str position: Example value "col-1 row-1"
-        :param str plugin_widget_name: Example value "Dummy".
-        :param str plugin_widget_name_with_dimensions: Example value "Dummy (1x1)".
-        :param str plugin_widget_css_class: Example value "plugin-dummy1x1".
+        :param string position: Example value "col-1 row-1"
+        :param string plugin_widget_name: Example value "Dummy".
+        :param string plugin_widget_name_with_dimensions: Example value "Dummy (1x1)".
+        :param string plugin_widget_css_class: Example value "plugin-dummy1x1".
         :param list added_plugin_widget_css_classes: Example value ['width-1', 'height-1'].
         :param dict form_data: Example value {'title': "Lorem", 'text': "Lorem ipsum dolor sit amet"}.
         :param callable form_hook_func: Function to when add form is opened (to populate the data).
@@ -485,8 +495,8 @@ class DashBrowserTest(LiveServerTestCase):
         """
         Test edit any single plugin.
 
-        :param str plugin_widget_name: Example value "Dummy".
-        :param str plugin_widget_css_class: Example value "plugin-dummy1x1".
+        :param string plugin_widget_name: Example value "Dummy".
+        :param string plugin_widget_css_class: Example value "plugin-dummy1x1".
         :param dict form_data: Example value {'title': "Lorem", 'text': "Lorem ipsum dolor sit amet"}.
         :param callable form_hook_func: Function to when edit form is opened (to populate the data).
 
@@ -639,7 +649,7 @@ class DashBrowserTest(LiveServerTestCase):
         """
         Test delete any single plugin.
 
-        :param str plugin_widget_css_class: Example value "plugin-dummy1x1".
+        :param string plugin_widget_css_class: Example value "plugin-dummy1x1".
 
         :example:
 
